| as_list_col | R Documentation |
Convert an rvec or matrix to a list that can be used as a list column in a data frame.
as_list_col(x)
## S3 method for class 'rvec'
as_list_col(x)
## S3 method for class 'matrix'
as_list_col(x)
x |
An rvecs or matrix. |
A list:
If x is an rvec, then the list contains
length(x) vectors, each of which has
n_draw(x) elements.
If x is a matrix, then the list contains
nrow(x) vectors, each of which has
ncol(x) elements.
rvec() Construct an rvec.
expand_from_rvec() Convert a data frame
from 'rvec' format to 'draw-and-value' format
Functions for summarising and plotting distributions in package ggdist use list columns (among other formats).
l <- list(1:3,
4:6)
r <- rvec(l)
as_list_col(r)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.