View source: R/distributions.R
| dbinom_rvec | R Documentation |
Density, distribution function, quantile function and random generation for the binomial distribution, modified to work with rvecs.
dbinom_rvec(x, size, prob, log = FALSE)
pbinom_rvec(q, size, prob, lower.tail = TRUE, log.p = FALSE)
qbinom_rvec(p, size, prob, lower.tail = TRUE, log.p = FALSE)
rbinom_rvec(n, size, prob, n_draw = NULL)
x |
Quantiles. Can be an rvec. |
size |
Number of trials.
See |
prob |
Probability of success in each trial.
See |
log, log.p |
Whether to return results
on a log scale. Default is
|
q |
Quantiles. Can be an rvec. |
lower.tail |
Whether to return
|
p |
Probabilities. Can be an rvec. |
n |
The length of random vector being created. Cannot be an rvec. |
n_draw |
Number of random draws in the random vector being created. Cannot be an rvec. |
Functions dbinom_rvec(), pbinom_rvec(),
pbinom_rvec() and rbinom_rvec() work like
base R functions dbinom(), pbinom(),
qbinom(), and rbinom(), except that
they accept rvecs as inputs. If any
input is an rvec, then the output will be too.
Function rbinom_rvec() also returns an
rvec if a value for n_draw is supplied.
dbinom_rvec(), pbinom_rvec(),
pbinom_rvec() and rbinom_rvec()
use tidyverse
vector recycling rules:
Vectors of length 1 are recycled
All other vectors must have the same size
If any of the arguments are rvecs,
or if a value for n_draw is supplied,
then an rvec; otherwise an ordinary R vector.
Unlike base rbinom(), rbinom_rvec()
always returns doubles.
dbinom(), pbinom(), qbinom(), rbinom() Base R equivalents
distributions All base R distributions
x <- rvec(list(c(3, 8),
c(0, 2)))
dbinom_rvec(x, size = 8, prob = 0.3)
pbinom_rvec(x, size = 8, prob = 0.3)
rbinom_rvec(n = 2,
size = 10,
prob = c(0.7, 0.3),
n_draw = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.