View source: R/distributions.R
| dchisq_rvec | R Documentation |
Density, distribution function, quantile function and random generation for the chi-squared distribution, modified to work with rvecs.
dchisq_rvec(x, df, ncp = 0, log = FALSE)
pchisq_rvec(q, df, ncp = 0, lower.tail = TRUE, log.p = FALSE)
qchisq_rvec(p, df, ncp = 0, lower.tail = TRUE, log.p = FALSE)
rchisq_rvec(n, df, ncp = 0, n_draw = NULL)
x |
Quantiles. Can be an rvec. |
df |
Degrees of freedom.
See |
ncp |
Non-centrality parameter.
Default is |
log, log.p |
Whether to return results
on a log scale. Default is
|
q |
Quantiles. Can be an rvec. |
lower.tail |
Whether to return
|
p |
Probabilities. Can be an rvec. |
n |
The length of random vector being created. Cannot be an rvec. |
n_draw |
Number of random draws in the random vector being created. Cannot be an rvec. |
Functions dchisq_rvec(), pchisq_rvec(),
pchisq_rvec() and rchisq_rvec() work like
base R functions dchisq(), pchisq(),
qchisq(), and rchisq(), except that
they accept rvecs as inputs. If any
input is an rvec, then the output will be too.
Function rchisq_rvec() also returns an
rvec if a value for n_draw is supplied.
dchisq_rvec(), pchisq_rvec(),
pchisq_rvec() and rchisq_rvec()
use tidyverse
vector recycling rules:
Vectors of length 1 are recycled
All other vectors must have the same size
If any of the arguments are rvecs,
or if a value for n_draw is supplied,
then an rvec; otherwise an ordinary R vector.
dchisq(), pchisq(), qchisq(), rchisq() Base R equivalents
distributions All base R distributions
x <- rvec(list(c(3, 5.1),
c(0.1, 2.3)))
dchisq_rvec(x, df = 3)
pchisq_rvec(x, df = 3)
rchisq_rvec(n = 2,
df = 3:4,
n_draw = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.