View source: R/distributions.R
| df_rvec | R Documentation |
Density, distribution function, quantile function and random generation for the F distribution, modified to work with rvecs.
df_rvec(x, df1, df2, ncp = 0, log = FALSE)
pf_rvec(q, df1, df2, ncp = 0, lower.tail = TRUE, log.p = FALSE)
qf_rvec(p, df1, df2, ncp = 0, lower.tail = TRUE, log.p = FALSE)
rf_rvec(n, df1, df2, ncp = 0, n_draw = NULL)
x |
Quantiles. Can be an rvec. |
df1, df2 |
Degrees of freedom.
See |
ncp |
Non-centrality parameter.
Default is |
log, log.p |
Whether to return results
on a log scale. Default is
|
q |
Quantiles. Can be an rvec. |
lower.tail |
Whether to return
|
p |
Probabilities. Can be an rvec. |
n |
The length of random vector being created. Cannot be an rvec. |
n_draw |
Number of random draws in the random vector being created. Cannot be an rvec. |
Functions df_rvec(), pf_rvec(),
pf_rvec() and rf_rvec() work like
base R functions df(), pf(),
qf(), and rf(), except that
they accept rvecs as inputs. If any
input is an rvec, then the output will be too.
Function rf_rvec() also returns an
rvec if a value for n_draw is supplied.
df_rvec(), pf_rvec(),
pf_rvec() and rf_rvec()
use tidyverse
vector recycling rules:
Vectors of length 1 are recycled
All other vectors must have the same size
If any of the arguments are rvecs,
or if a value for n_draw is supplied,
then an rvec
Otherwise an ordinary R vector.
df(), pf(), qf(), rf() Base R equivalents
distributions All base R distributions
x <- rvec(list(c(3, 5.1),
c(0.1, 2.3)))
df_rvec(x, df1 = 1, df2 = 3)
pf_rvec(x, df1 = 1, df2 = 3)
rf_rvec(n = 2, df1 = 1,df2 = 2:3, n_draw = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.