dgeom_rvec: Geometric Distribution, Using Multiple Draws

View source: R/distributions.R

dgeom_rvecR Documentation

Geometric Distribution, Using Multiple Draws

Description

Density, distribution function, quantile function and random generation for the geometric distribution, modified to work with rvecs.

Usage

dgeom_rvec(x, prob, log = FALSE)

pgeom_rvec(q, prob, lower.tail = TRUE, log.p = FALSE)

qgeom_rvec(p, prob, lower.tail = TRUE, log.p = FALSE)

rgeom_rvec(n, prob, n_draw = NULL)

Arguments

x

Quantiles. Can be an rvec.

prob

Probability of success in each trial. See dgeom(). Can be an rvec.

log, log.p

Whether to return results on a log scale. Default is FALSE. Cannot be an rvec.

q

Quantiles. Can be an rvec.

lower.tail

Whether to return P[X \le x], as opposed to P[X > x]. Default is TRUE. Cannot be an rvec.

p

Probabilities. Can be an rvec.

n

The length of random vector being created. Cannot be an rvec.

n_draw

Number of random draws in the random vector being created. Cannot be an rvec.

Details

Functions dgeom_rvec(), pgeom_rvec(), pgeom_rvec() and rgeom_rvec() work like base R functions dgeom(), pgeom(), qgeom(), and rgeom(), except that they accept rvecs as inputs. If any input is an rvec, then the output will be too. Function rgeom_rvec() also returns an rvec if a value for n_draw is supplied.

dgeom_rvec(), pgeom_rvec(), pgeom_rvec() and rgeom_rvec() use tidyverse vector recycling rules:

  • Vectors of length 1 are recycled

  • All other vectors must have the same size

Value

  • If any of the arguments are rvecs, or if a value for n_draw is supplied, then an rvec; otherwise an ordinary R vector.

  • Unlike base rgeom(), rgeom_rvec() always returns doubles.

See Also

  • dgeom(), pgeom(), qgeom(), rgeom() Base R equivalents

  • distributions All base R distributions

Examples

x <- rvec(list(c(3, 5),
               c(0, 2)))
dgeom_rvec(x, prob = 0.3)
pgeom_rvec(x, prob = 0.3)

rgeom_rvec(n = 2,
           prob = c(0.5, 0.8),
           n_draw = 1000)

rvec documentation built on Dec. 10, 2025, 5:08 p.m.