View source: R/distributions.R
| dpois_rvec | R Documentation |
Density, distribution function, quantile function and random generation for the Poisson distribution, modified to work with rvecs.
dpois_rvec(x, lambda, log = FALSE)
ppois_rvec(q, lambda, lower.tail = TRUE, log.p = FALSE)
qpois_rvec(p, lambda, lower.tail = TRUE, log.p = FALSE)
rpois_rvec(n, lambda, n_draw = NULL)
x |
Quantiles. Can be an rvec. |
lambda |
Vector of means.
See |
log, log.p |
Whether to return results
on a log scale. Default is
|
q |
Quantiles. Can be an rvec. |
lower.tail |
Whether to return
|
p |
Probabilities. Can be an rvec. |
n |
The length of random vector being created. Cannot be an rvec. |
n_draw |
Number of random draws in the random vector being created. Cannot be an rvec. |
Functions dpois_rvec(), ppois_rvec(),
ppois_rvec() and rpois_rvec() work like
base R functions dpois(), ppois(),
qpois(), and rpois(), except that
they accept rvecs as inputs. If any
input is an rvec, then the output will be too.
Function rpois_rvec() also returns an
rvec if a value for n_draw is supplied.
dpois_rvec(), ppois_rvec(),
ppois_rvec() and rpois_rvec()
use tidyverse
vector recycling rules:
Vectors of length 1 are recycled
All other vectors must have the same size
If any of the arguments are rvecs,
or if a value for n_draw is supplied,
then an rvec; otherwise an ordinary R vector.
Unlike base rpois(), rpois_rvec()
always returns doubles.
dpois(), ppois(), qpois(), rpois() Base R equivalents
distributions All base R distributions
x <- rvec(list(c(3, 5),
c(1, 2)))
dpois_rvec(x, lambda = 3)
ppois_rvec(x, lambda = 3)
rpois_rvec(n = 2,
lambda = c(5, 10),
n_draw = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.