Get a count of the random draws
held by x. If x
does not hold random draws, then n_draw()
throws an error.
Arguments
- x
An object that holds random draws, eg an rvec.
Value
A positive integer scalar. An rvec always has at least one draw, including when it has zero elements.
See also
extract_draws()to select draws using indices.thin_draws()to randomly reduce the number of draws.is_rvec()to test if an object is an rvec.