| sd | R Documentation |
Calculate standard deviation of x, where x can be
an rvec. If x is an rvec, separate standard deviations
are calculated for each draw.
sd(x, na.rm = FALSE)
x |
A numeric vector or R object, including an |
na.rm |
Whether to remove |
To enable different behavior for rvecs and for ordinary vectors,
the base R function stats::sd() is turned into a generic,
with stats::sd() as the default.
For details on the calculations, see the documentation
for stats::sd().
An rvec, if x is an rvec. Otherwise
typically a numeric vector.
var()
x <- rvec(cbind(rnorm(10), rnorm(10, sd = 20)))
x
sd(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.